@@ -1,38 +1,13 @@
-use crate::vocab;
+use crate::vocab::{Vocab, WordPieceVocab, BPEVocab};
 #[test]
 fn creating_vocab() {
-    let _new_vocab = vocab::Vocab::new();
-    let _bpe_vocab = vocab::load_bpe_vocab();
-}
-
-#[test]
-fn adding_tokens() {
-    let mut new_vocab = vocab::Vocab::new();
-    // Single token
-    new_vocab.add_token(String::from("hello"));
-    assert_eq!(new_vocab.num_tokens, 5); // 4 initial tokens, plus added one
-    
-    // Many tokens
-    new_vocab.add_tokens(vec![String::from("hi"), String::from("howdy"), String::from("how goes")]);
-    assert_eq!(new_vocab.num_tokens, 8); // 4 initial tokens plus 4 added
-}
-
-#[test]
-fn removing_tokens() {
-    let mut new_vocab = vocab::Vocab::new();
-    new_vocab.add_tokens(vec![String::from("hi"), String::from("howdy"), String::from("how goes")]);
-    // Single token
-    new_vocab.remove_token(String::from("hi"));
-    assert_eq!(new_vocab.num_tokens, 6);
-    
-    // Many tokens
-    new_vocab.remove_tokens(vec![String::from("howdy"), String::from("how goes")]);
-    assert_eq!(new_vocab.num_tokens, 4);
+    let _wordpiece_vocab = WordPieceVocab::load();
+    let _bpe_vocab = BPEVocab::load();
 }
 
 #[test]
 fn indexes_from_tokens_bpe() {
-    let bpe_vocab = vocab::load_bpe_vocab();
+    let bpe_vocab = BPEVocab::load();
     let tokens = ["Hello", ",", " ", "how", " ", "are", " ", "you", "?"];
     let mut tokens_vec: Vec<String> = Vec::new();
     for token in tokens.iter(){
@@ -44,7 +19,7 @@ fn indexes_from_tokens_bpe() {
 
 #[test]
 fn indexes_from_tokens_wordpiece() {
-    let wordpiece_vocab = vocab::load_wordpiece_vocab();
+    let wordpiece_vocab = WordPieceVocab::load();
     let tokens = ["hello", ",", "how", "are", "you", "?"];
     let mut tokens_vec: Vec<String> = Vec::new();
     for token in tokens.iter(){
@@ -56,7 +31,7 @@ fn indexes_from_tokens_wordpiece() {
 
 #[test]
 fn tokens_from_indexes_bpe() {
-    let bpe_vocab = vocab::load_bpe_vocab();
+    let bpe_vocab = BPEVocab::load();
     let tokens = ["Hello", ",", " ", "how", " ", "are", " ", "you", "?"];
     let mut tokens_vec: Vec<String> = Vec::new();
     for token in tokens.iter(){
@@ -68,7 +43,7 @@ fn tokens_from_indexes_bpe() {
 
 #[test]
 fn tokens_from_indexes_wordpiece() {
-    let wordpiece_vocab = vocab::load_wordpiece_vocab();
+    let wordpiece_vocab = WordPieceVocab::load();
     let tokens = ["hello", ",", "how", "are", "you", "?"];
     let mut tokens_vec: Vec<String> = Vec::new();
     for token in tokens.iter(){
@@ -80,7 +55,7 @@ fn tokens_from_indexes_wordpiece() {
 
 #[test]
 fn batch_indexes_from_tokens() {
-    let bpe_vocab = vocab::load_bpe_vocab();
+    let bpe_vocab = BPEVocab::load();
     let tokens = ["Hello", ",", " ", "how", " ", "are", " ", "you", "?"];
     let mut tokens_vec: Vec<Vec<String>> = vec![Vec::new()];
     for token in tokens.iter(){
@@ -92,7 +67,7 @@ fn batch_indexes_from_tokens() {
 
 #[test]
 fn batch_tokens_from_indexes() {
-    let bpe_vocab = vocab::load_bpe_vocab();
+    let bpe_vocab = BPEVocab::load();
     let tokens = ["Hello", ",", " ", "how", " ", "are", " ", "you", "?"];
     let mut tokens_vec: Vec<String> = Vec::new();
     for token in tokens.iter(){
